==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/AssemblyPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.AssemblyPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The assembly properties definition.
 * @property assemblyCulture The assembly culture.
 * @property assemblyName The assembly name.
 * @property assemblyPublicKeyToken The assembly public key token.
 * @property assemblyVersion The assembly version.
 * @property changedTime The artifact changed time.
 * @property content
 * @property contentLink The content link.
 * @property contentType The content type.
 * @property createdTime The artifact creation time.
 * @property metadata
 */
public data class AssemblyPropertiesArgs(
    public val assemblyCulture: Output<String>? = null,
    public val assemblyName: Output<String>,
    public val assemblyPublicKeyToken: Output<String>? = null,
    public val assemblyVersion: Output<String>? = null,
    public val changedTime: Output<String>? = null,
    public val content: Output<Any>? = null,
    public val contentLink: Output<ContentLinkArgs>? = null,
    public val contentType: Output<String>? = null,
    public val createdTime: Output<String>? = null,
    public val metadata: Output<Any>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.logic.inputs.AssemblyPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.logic.inputs.AssemblyPropertiesArgs =
        com.pulumi.azurenative.logic.inputs.AssemblyPropertiesArgs.builder()
            .assemblyCulture(assemblyCulture?.applyValue({ args0 -> args0 }))
            .assemblyName(assemblyName.applyValue({ args0 -> args0 }))
            .assemblyPublicKeyToken(assemblyPublicKeyToken?.applyValue({ args0 -> args0 }))
            .assemblyVersion(assemblyVersion?.applyValue({ args0 -> args0 }))
            .changedTime(changedTime?.applyValue({ args0 -> args0 }))
            .content(content?.applyValue({ args0 -> args0 }))
            .contentLink(contentLink?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .contentType(contentType?.applyValue({ args0 -> args0 }))
            .createdTime(createdTime?.applyValue({ args0 -> args0 }))
            .metadata(metadata?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AssemblyPropertiesArgs].
 */
@PulumiTagMarker
public class AssemblyPropertiesArgsBuilder internal constructor() {
    private var assemblyCulture: Output<String>? = null

    private var assemblyName: Output<String>? = null

    private var assemblyPublicKeyToken: Output<String>? = null

    private var assemblyVersion: Output<String>? = null

    private var changedTime: Output<String>? = null

    private var content: Output<Any>? = null

    private var contentLink: Output<ContentLinkArgs>? = null

    private var contentType: Output<String>? = null

    private var createdTime: Output<String>? = null

    private var metadata: Output<Any>? = null

    /**
     * @param value The assembly culture.
     */
    @JvmName("qtbxaibdpjqaiepl")
    public suspend fun assemblyCulture(`value`: Output<String>) {
        this.assemblyCulture = value
    }

    /**
     * @param value The assembly name.
     */
    @JvmName("hwmumemunjwwayiy")
    public suspend fun assemblyName(`value`: Output<String>) {
        this.assemblyName = value
    }

    /**
     * @param value The assembly public key token.
     */
    @JvmName("aksghunpvsecnshv")
    public suspend fun assemblyPublicKeyToken(`value`: Output<String>) {
        this.assemblyPublicKeyToken = value
    }

    /**
     * @param value The assembly version.
     */
    @JvmName("jjowyvpkilmarkdk")
    public suspend fun assemblyVersion(`value`: Output<String>) {
        this.assemblyVersion = value
    }

    /**
     * @param value The artifact changed time.
     */
    @JvmName("ctvxsdcicprkalgx")
    public suspend fun changedTime(`value`: Output<String>) {
        this.changedTime = value
    }

    /**
     * @param value
     */
    @JvmName("tsierraukumfygqd")
    public suspend fun content(`value`: Output<Any>) {
        this.content = value
    }

    /**
     * @param value The content link.
     */
    @JvmName("kyqlfhkhgjfgdqtm")
    public suspend fun contentLink(`value`: Output<ContentLinkArgs>) {
        this.contentLink = value
    }

    /**
     * @param value The content type.
     */
    @JvmName("nywlhmjqidoamoeo")
    public suspend fun contentType(`value`: Output<String>) {
        this.contentType = value
    }

    /**
     * @param value The artifact creation time.
     */
    @JvmName("poaansipxwvxtsrw")
    public suspend fun createdTime(`value`: Output<String>) {
        this.createdTime = value
    }

    /**
     * @param value
     */
    @JvmName("opxputxreyjgcurr")
    public suspend fun metadata(`value`: Output<Any>) {
        this.metadata = value
    }

    /**
     * @param value The assembly culture.
     */
    @JvmName("sjfgltusaefkgryt")
    public suspend fun assemblyCulture(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.assemblyCulture = mapped
    }

    /**
     * @param value The assembly name.
     */
    @JvmName("eohibmkmiacjjtbi")
    public suspend fun assemblyName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.assemblyName = mapped
    }

    /**
     * @param value The assembly public key token.
     */
    @JvmName("uydctleaiulkkmof")
    public suspend fun assemblyPublicKeyToken(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.assemblyPublicKeyToken = mapped
    }

    /**
     * @param value The assembly version.
     */
    @JvmName("layyaiqpdmyamphe")
    public suspend fun assemblyVersion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.assemblyVersion = mapped
    }

    /**
     * @param value The artifact changed time.
     */
    @JvmName("acqcqebwtgtybaxe")
    public suspend fun changedTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.changedTime = mapped
    }

    /**
     * @param value
     */
    @JvmName("bjxoxuafsxqagkxh")
    public suspend fun content(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.content = mapped
    }

    /**
     * @param value The content link.
     */
    @JvmName("fkrkxmndxmkmoaei")
    public suspend fun contentLink(`value`: ContentLinkArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.contentLink = mapped
    }

    /**
     * @param argument The content link.
     */
    @JvmName("ngahdhkefyrmtfkb")
    public suspend fun contentLink(argument: suspend ContentLinkArgsBuilder.() -> Unit) {
        val toBeMapped = ContentLinkArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.contentLink = mapped
    }

    /**
     * @param value The content type.
     */
    @JvmName("juudlcshplkhdvct")
    public suspend fun contentType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.contentType = mapped
    }

    /**
     * @param value The artifact creation time.
     */
    @JvmName("hbwquhkfuejyffgv")
    public suspend fun createdTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.createdTime = mapped
    }

    /**
     * @param value
     */
    @JvmName("skkjgxlvanmkmklb")
    public suspend fun metadata(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.metadata = mapped
    }

    internal fun build(): AssemblyPropertiesArgs = AssemblyPropertiesArgs(
        assemblyCulture = assemblyCulture,
        assemblyName = assemblyName ?: throw PulumiNullFieldException("assemblyName"),
        assemblyPublicKeyToken = assemblyPublicKeyToken,
        assemblyVersion = assemblyVersion,
        changedTime = changedTime,
        content = content,
        contentLink = contentLink,
        contentType = contentType,
        createdTime = createdTime,
        metadata = metadata,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/AssemblyPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.AssemblyPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The assembly properties definition.
 * @property assemblyCulture The assembly culture.
 * @property assemblyName The assembly name.
 * @property assemblyPublicKeyToken The assembly public key token.
 * @property assemblyVersion The assembly version.
 * @property changedTime The artifact changed time.
 * @property content
 * @property contentLink The content link.
 * @property contentType The content type.
 * @property createdTime The artifact creation time.
 * @property metadata
 */
public data class AssemblyPropertiesArgs(
    public val assemblyCulture: Output<String>? = null,
    public val assemblyName: Output<String>,
    public val assemblyPublicKeyToken: Output<String>? = null,
    public val assemblyVersion: Output<String>? = null,
    public val changedTime: Output<String>? = null,
    public val content: Output<Any>? = null,
    public val contentLink: Output<ContentLinkArgs>? = null,
    public val contentType: Output<String>? = null,
    public val createdTime: Output<String>? = null,
    public val metadata: Output<Any>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.logic.inputs.AssemblyPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.logic.inputs.AssemblyPropertiesArgs =
        com.pulumi.azurenative.logic.inputs.AssemblyPropertiesArgs.builder()
            .assemblyCulture(assemblyCulture?.applyValue({ args0 -> args0 }))
            .assemblyName(assemblyName.applyValue({ args0 -> args0 }))
            .assemblyPublicKeyToken(assemblyPublicKeyToken?.applyValue({ args0 -> args0 }))
            .assemblyVersion(assemblyVersion?.applyValue({ args0 -> args0 }))
            .changedTime(changedTime?.applyValue({ args0 -> args0 }))
            .content(content?.applyValue({ args0 -> args0 }))
            .contentLink(contentLink?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .contentType(contentType?.applyValue({ args0 -> args0 }))
            .createdTime(createdTime?.applyValue({ args0 -> args0 }))
            .metadata(metadata?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AssemblyPropertiesArgs].
 */
@PulumiTagMarker
public class AssemblyPropertiesArgsBuilder internal constructor() {
    private var assemblyCulture: Output<String>? = null

    private var assemblyName: Output<String>? = null

    private var assemblyPublicKeyToken: Output<String>? = null

    private var assemblyVersion: Output<String>? = null

    private var changedTime: Output<String>? = null

    private var content: Output<Any>? = null

    private var contentLink: Output<ContentLinkArgs>? = null

    private var contentType: Output<String>? = null

    private var createdTime: Output<String>? = null

    private var metadata: Output<Any>? = null

    /**
     * @param value The assembly culture.
     */
    @JvmName("dibkwifylivnmekq")
    public suspend fun assemblyCulture(`value`: Output<String>) {
        this.assemblyCulture = value
    }

    /**
     * @param value The assembly name.
     */
    @JvmName("lniiphpypwuamouw")
    public suspend fun assemblyName(`value`: Output<String>) {
        this.assemblyName = value
    }

    /**
     * @param value The assembly public key token.
     */
    @JvmName("rueghlxypxlvrmqo")
    public suspend fun assemblyPublicKeyToken(`value`: Output<String>) {
        this.assemblyPublicKeyToken = value
    }

    /**
     * @param value The assembly version.
     */
    @JvmName("ickaiqbtjpyttuqn")
    public suspend fun assemblyVersion(`value`: Output<String>) {
        this.assemblyVersion = value
    }

    /**
     * @param value The artifact changed time.
     */
    @JvmName("rbwlyrrtatfwjrlc")
    public suspend fun changedTime(`value`: Output<String>) {
        this.changedTime = value
    }

    /**
     * @param value
     */
    @JvmName("oyotovuhhyygnptr")
    public suspend fun content(`value`: Output<Any>) {
        this.content = value
    }

    /**
     * @param value The content link.
     */
    @JvmName("twveueafsallhyai")
    public suspend fun contentLink(`value`: Output<ContentLinkArgs>) {
        this.contentLink = value
    }

    /**
     * @param value The content type.
     */
    @JvmName("jkddywdiguhpergi")
    public suspend fun contentType(`value`: Output<String>) {
        this.contentType = value
    }

    /**
     * @param value The artifact creation time.
     */
    @JvmName("xuulaxcabcogvyjh")
    public suspend fun createdTime(`value`: Output<String>) {
        this.createdTime = value
    }

    /**
     * @param value
     */
    @JvmName("skijfnqwxiyrhuum")
    public suspend fun metadata(`value`: Output<Any>) {
        this.metadata = value
    }

    /**
     * @param value The assembly culture.
     */
    @JvmName("rhgpcjxkmvqpborw")
    public suspend fun assemblyCulture(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.assemblyCulture = mapped
    }

    /**
     * @param value The assembly name.
     */
    @JvmName("rmxniehbmoeqhcxm")
    public suspend fun assemblyName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.assemblyName = mapped
    }

    /**
     * @param value The assembly public key token.
     */
    @JvmName("fyubmvsmpqvgghra")
    public suspend fun assemblyPublicKeyToken(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.assemblyPublicKeyToken = mapped
    }

    /**
     * @param value The assembly version.
     */
    @JvmName("lnncpuvdpdibltwn")
    public suspend fun assemblyVersion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.assemblyVersion = mapped
    }

    /**
     * @param value The artifact changed time.
     */
    @JvmName("ybqqybvcxavwqvfv")
    public suspend fun changedTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.changedTime = mapped
    }

    /**
     * @param value
     */
    @JvmName("xijetddiilywuerq")
    public suspend fun content(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.content = mapped
    }

    /**
     * @param value The content link.
     */
    @JvmName("jiuxjcoyettyjthj")
    public suspend fun contentLink(`value`: ContentLinkArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.contentLink = mapped
    }

    /**
     * @param argument The content link.
     */
    @JvmName("khjhbumqoxuqrehu")
    public suspend fun contentLink(argument: suspend ContentLinkArgsBuilder.() -> Unit) {
        val toBeMapped = ContentLinkArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.contentLink = mapped
    }

    /**
     * @param value The content type.
     */
    @JvmName("brjwqmvkoptxxpse")
    public suspend fun contentType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.contentType = mapped
    }

    /**
     * @param value The artifact creation time.
     */
    @JvmName("hvmtfjholkucihvl")
    public suspend fun createdTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.createdTime = mapped
    }

    /**
     * @param value
     */
    @JvmName("onhmsdvdhupyftbi")
    public suspend fun metadata(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.metadata = mapped
    }

    internal fun build(): AssemblyPropertiesArgs = AssemblyPropertiesArgs(
        assemblyCulture = assemblyCulture,
        assemblyName = assemblyName ?: throw PulumiNullFieldException("assemblyName"),
        assemblyPublicKeyToken = assemblyPublicKeyToken,
        assemblyVersion = assemblyVersion,
        changedTime = changedTime,
        content = content,
        contentLink = contentLink,
        contentType = contentType,
        createdTime = createdTime,
        metadata = metadata,
    )
}
